OrgUnifiedpushDistributor2 class

Constructors

OrgUnifiedpushDistributor2(DBusClient client, String distributor)

Properties

client → DBusClient
The client this object is accessed from.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the client providing this object.
finalinherited
path → DBusObjectPath
The path to the object.
finalinherited
propertiesChanged ↔ Stream<DBusPropertiesChangedSignal>
Stream of signals when the remote object indicates a property has changed.
latefinalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

callMethod(String? interface, String name, Iterable<DBusValue> values, {DBusSignature? replySignature, bool noReplyExpected = false, bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<DBusMethodSuccessResponse>
Invokes a method on this object. Throws DBusMethodResponseException if the remote side returns an error.
inherited
callRegister(Map<String, DBusValue> args, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<Map<String, DBusValue>>
Invokes org.unifiedpush.Distributor2.Register()
callUnregister(Map<String, DBusValue> args, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<Map<String, DBusValue>>
Invokes org.unifiedpush.Distributor2.Unregister()
getAllProperties(String interface) → Future<Map<String, DBusValue>>
Gets the values of all the properties on this object.
inherited
getProperty(String interface, String name, {DBusSignature? signature}) → Future<DBusValue>
Gets a property on this object.
inherited
introspect() → Future<DBusIntrospectNode>
Gets the introspection data for this object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setProperty(String interface, String name, DBusValue value) → Future<void>
Sets a property on this object.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited